﻿/* ------------------------------------------------------------------------ */
/* xlauto.h - C-Funktionen zur Automatisierung von Microsoft Excel          */
/*                                                                          */
/*                  Copyright Tilman Kuepper 2017.                          */
/*    Distributed under the Boost Software License, Version 1.0.            */
/*        (See accompanying file LICENSE_1_0.txt or copy at                 */
/*               http://www.boost.org/LICENSE_1_0.txt)                      */
/*                                                                          */
/* Letzte Bearbeitung: 11. Maerz 2017                                       */
/* ------------------------------------------------------------------------ */

#ifndef HM_XLAUTO_H_Included
#define HM_XLAUTO_H_Included

#include <stddef.h>  /* size_t */

#ifdef __cplusplus
extern "C" {
#endif

/* ------------------------------------------------------------------------ */
/* Liste der moeglichen Funktions-Rueckgabewerte bzw. Fehler-Codes          */
/* ------------------------------------------------------------------------ */

/* Die angegebene Zelle ist leer */
#define XL_EMPTY 1
    
/* Die angegebene Zelle ist nicht leer */
#define XL_NOT_EMPTY 0
    
/* Funktion erfolgreich beendet */
#define XL_OK 0

/* Excel kann nicht gestartet werden, da es bereits laeuft */
#define XL_ERR_ALREADY_RUNNING -1

/* Excel kann nicht gestartet werden, da es nicht korrekt installiert ist */
#define XL_ERR_NOT_INSTALLED -2

/* Excel wurde noch nicht gestartet */
#define XL_ERR_NOT_RUNNING -3

/* Der uebergebene (Datei- oder Arbeitsblatt-)Name wurde nicht gefunden */
#define XL_ERR_NOT_FOUND -4

/* Der Wert konnte nicht an die angegebene Position geschrieben werden */
#define XL_ERR_WRITE_FAILED -5

/* Die Zelle an der angegebenen Position konnte nicht ausgelesen werden */
#define XL_ERR_READ_FAILED -6

/* Fehler beim Speichern der Excel-Datei aufgetreten*/
#define XL_ERR_SAVE_FAILED -7

/* ------------------------------------------------------------------------ */
/* Uebergabeparameter fuer XL_Connect                                       */
/* ------------------------------------------------------------------------ */

#define XL_HIDE_WINDOW 0  /* Excel-Applikation sichtbar machen */
#define XL_SHOW_WINDOW 1  /* Excel-Applikation verbergen       */

/* ------------------------------------------------------------------------ */
/* Uebergabeparameter fuer XL_Disconnect                                    */
/* ------------------------------------------------------------------------ */

#define XL_CLOSE     0  /* Excel-Applikation sofort schliessen */
#define XL_STAY_OPEN 1  /* Excel-Applikation geoeffnet lassen  */

/* ------------------------------------------------------------------------ */
/* Verbindung zu Microsoft Excel herstellen. Der Parameter show_window gibt */
/* an, ob Excel sichtbar (XL_SHOW_WINDOW) oder unsichtbar (XL_HIDE_WINDOW)  */
/* gestartet werden soll. Mit dem Parameter filename wird der Name der zu   */
/* oeffnenden Excel-Datei uebergeben, bzw. filename == NULL, falls keine    */
/* Datei geoeffnet werden soll. Rueckgabewert: XL_OK, XL_ERR_NOT_FOUND,     */
/* XL_ERR_NOT_INSTALLED oder XL_ERR_ALREADY_RUNNING                         */
/* ------------------------------------------------------------------------ */
int XL_Connect(const char *filename, int show_window);

/* ------------------------------------------------------------------------ */
/* Verbindung zu Microsoft Excel beenden, bei mode == XL_STAY_OPEN bleibt   */
/* Excel weiterhin offen, bei mode == XL_CLOSE wird Excel geschlossen.      */
/* Rueckgabewert: XL_OK oder XL_ERR_NOT_RUNNING                             */
/* ------------------------------------------------------------------------ */
int XL_Disconnect(int mode);

/* ------------------------------------------------------------------------ */
/* Innerhalb der aktuellen Excel-Arbeitsmappe wird das Arbeitsblatt mit     */
/* dem angegebenen Namen (zum Beispiel "Tabelle1") gesucht und aktiviert.   */
/* Rueckgabewert: XL_OK, XL_ERR_NOT_RUNNING oder XL_ERR_NOT_FOUND           */
/* ------------------------------------------------------------------------ */
int XL_SelectWorksheet(const char *name);

/* ------------------------------------------------------------------------ */
/* Eine Integer-Zahl wird an der angegebenen Position in das Arbeitsblatt   */
/* geschrieben. Achtung: Die Zeilen-/Spaltennummerierung ist eins-basiert,  */
/* die oberste linke Zelle befindet sich an der Position row = 1, col = 1.  */
/* Rueckgabewert: XL_OK, XL_ERR_NOT_RUNNING oder XL_ERR_WRITE_FAILED        */
/* ------------------------------------------------------------------------ */
int XL_SetInteger(int row, int col, int value);

/* ------------------------------------------------------------------------ */
/* Eine Double-Zahl wird an der angegebenen Position in das Arbeitsblatt    */
/* geschrieben. Achtung: Die Zeilen-/Spaltennummerierung ist eins-basiert,  */
/* die oberste linke Zelle befindet sich an der Position row = 1, col = 1.  */
/* Rueckgabewert: XL_OK, XL_ERR_NOT_RUNNING oder XL_ERR_WRITE_FAILED        */
/* ------------------------------------------------------------------------ */
int XL_SetDouble(int row, int col, double value);

/* ------------------------------------------------------------------------ */
/* Ein String wird an der angegebenen Position in das Excel-Arbeitsblatt    */
/* geschrieben. Achtung: Die Zeilen-/Spaltennummerierung ist eins-basiert,  */
/* die oberste linke Zelle befindet sich an der Position row = 1, col = 1.  */
/* Rueckgabewert: XL_OK, XL_ERR_NOT_RUNNING oder XL_ERR_WRITE_FAILED        */
/* ------------------------------------------------------------------------ */
int XL_SetString(int row, int col, const char *value);
int XL_SetWString(int row, int col, const wchar_t *wvalue);

/* ------------------------------------------------------------------------ */
/* Die Integer-Zahl an der angegebenen Position des Arbeitsblatts wird      */
/* zurueckgegeben. Hinweis: Falls die Zelle an der angegebenen Position     */
/* leer ist, keine Zahl enthaelt oder ein Fehler auftritt (falls z. B.      */
/* Excel nicht gestartet wurde), ist der Rückgabewert gleich null.          */
/* ------------------------------------------------------------------------ */
int XL_GetInteger(int row, int col);

/* ------------------------------------------------------------------------ */
/* Die Double-Zahl an der angegebenen Position des Arbeitsblatts wird       */
/* zurueckgegeben. Hinweis: Falls die Zelle an der angegebenen Position     */
/* leer ist, keine Zahl enthaelt oder ein Fehler auftritt (falls z. B.      */
/* Excel nicht gestartet wurde), ist der Rückgabewert gleich null.          */
/* ------------------------------------------------------------------------ */
double XL_GetDouble(int row, int col);

/* ------------------------------------------------------------------------ */
/* Der Zellen-Inhalt an der angegebenen Position des Arbeitsblatts wird     */
/* als String zurueckgegeben. Beim Aufruf der Funktion XL_GetString muss    */
/* ein Zeiger (result) auf einen Buffer von ausreichender Groesse (len)     */
/* fuer die Rueckgabe des Zellen-Inhalts bereitgestellt werden.             */
/* Rueckgabewert: XL_OK, XL_ERR_NOT_RUNNING oder XL_ERR_READ_FAILED         */
/* ------------------------------------------------------------------------ */
int XL_GetString(int row, int col, char *result, size_t len);

/* ----------------------------------------------------------------------- */
/* Eine Zelle (Reihe = row, Spalte = col) im aktuellen Excel-Arbeitsblatt  */
/* wird darauf ueberprueft, ob sie leer ist oder nicht. Rueckgabewert:     */
/* XL_EMPTY, XL_NOT_EMPTY, XL_ERR_READ_FAILED oder XL_ERR_NOT_RUNNING      */
/* ----------------------------------------------------------------------- */
int XL_IsEmpty(int row, int col);

/* ----------------------------------------------------------------------- */
/* Die aktuelle Arbeitsmappe wird unter dem angegebenen Dateinamen auf der */
/* Festplatte gespeichert. Rückgabewerte: XL_OK, XL_ERR_NOT_RUNNING oder   */
/* XL_ERR_SAVE_FAILED (falls beim Speichern ein Fehler aufgetreten ist).   */
/* ----------------------------------------------------------------------- */
int XL_SaveAs(const char *filename);

#ifdef __cplusplus
}
#endif

#endif  /* HM_XLAUTO_H_Included */
